![PyPI](https://img.shields.io/pypi/v/shell-whiz)
![GitHub stars](https://img.shields.io/github/stars/beimzhan/shell-whiz)
![GitHub commit activity](https://img.shields.io/github/commit-activity/m/beimzhan/shell-whiz)
![GitHub license](https://img.shields.io/github/license/beimzhan/shell-whiz)

# Shell Whiz: AI assistant right in your terminal
Shell Whiz will help you generate shell commands from your natural language queries. It is powered by OpenAI's `gpt-3.5-turbo` and is free to use.

## All features
- **Pay as you go:** you only pay for what you use; no subscription is required. Just receive an API key from https://platform.openai.com/account/api-keys.
- **Easy to install:** run `pip install shell-whiz` and you're good to go.
- **Easy to use:** Shell Whiz is a command-line tool.
    - Run `sw ask` to generate shell commands from your natural language queries.
    - Run `sw explain` to get an explanation of any shell command.

## License
Shell Whiz is licensed under the GNU General Public License v3.0. See [LICENSE](LICENSE) for more information.
